==> ejc-prjfinance-impl-3.0.1-20231220.082355-117-sources.jar: com/ejianc/business/prjfinance/bean/TaxCostEntity.java <==
package com.ejianc.business.prjfinance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 税务费用
 * 
 * @author generator
 * 
 */
 @TableName("ejc_prjfinance_tax_cost")
public class TaxCostEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="cost_id")
    private Long costId; // 费用类型
    @TableField(value="cost_name")
    private String costName; // 费用类型名称
    @TableField(value="back_or_del")
    private String backOrDel; // 单据类型
    @TableField(value="back_or_del_name")
    private String backOrDelName; // 单据类型名称
    @TableField(value="amount")
    private BigDecimal amount; // 金额
    @TableField(value="cost_time")
    private Date costTime; // 费用日期
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_department")
    private String employeeDepartment; // 经办人部门
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_code")
    private String billCode;
    @TableField(value="bill_state")
    private Integer billState;
    @TableField(value="org_id")
    private Long orgId;

    
    

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getCostId() {
        return costId;
    }

    public void setCostId(Long costId) {
        this.costId = costId;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public String getBackOrDel() {
        return backOrDel;
    }

    public void setBackOrDel(String backOrDel) {
        this.backOrDel = backOrDel;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public Date getCostTime() {
        return costTime;
    }

    public void setCostTime(Date costTime) {
        this.costTime = costTime;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getEmployeeDepartment() {
        return employeeDepartment;
    }

    public void setEmployeeDepartment(String employeeDepartment) {
        this.employeeDepartment = employeeDepartment;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getBillCode() {
        return billCode;
    }

    public String getBackOrDelName() {
        return backOrDelName;
    }

    public void setBackOrDelName(String backOrDelName) {
        this.backOrDelName = backOrDelName;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
}

==> ejc-prjfinance-impl-3.0.1-20240814.095553-139-sources.jar: com/ejianc/business/prjfinance/bean/TaxCostEntity.java <==
package com.ejianc.business.prjfinance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 税务费用
 * 
 * @author generator
 * 
 */
 @TableName("ejc_prjfinance_tax_cost")
public class TaxCostEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="cost_id")
    private Long costId; // 费用类型
    @TableField(value="cost_name")
    private String costName; // 费用类型名称
    @TableField(value="back_or_del")
    private String backOrDel; // 单据类型
    @TableField(value="back_or_del_name")
    private String backOrDelName; // 单据类型名称
    @TableField(value="amount")
    private BigDecimal amount; // 金额
    @TableField(value="cost_time")
    private Date costTime; // 费用日期
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_department")
    private String employeeDepartment; // 经办人部门
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_code")
    private String billCode;
    @TableField(value="bill_state")
    private Integer billState;
    @TableField(value="org_id")
    private Long orgId;

    @TableField(exist=false)
    @SubEntity(serviceName="taxCostInvoiceService")
    private List<TaxCostInvoiceEntity> taxCostInvoiceList = new ArrayList<>(); // 收票明细
    

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getCostId() {
        return costId;
    }

    public void setCostId(Long costId) {
        this.costId = costId;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public String getBackOrDel() {
        return backOrDel;
    }

    public void setBackOrDel(String backOrDel) {
        this.backOrDel = backOrDel;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public Date getCostTime() {
        return costTime;
    }

    public void setCostTime(Date costTime) {
        this.costTime = costTime;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public List<TaxCostInvoiceEntity> getTaxCostInvoiceList() {
        return taxCostInvoiceList;
    }

    public void setTaxCostInvoiceList(List<TaxCostInvoiceEntity> taxCostInvoiceList) {
        this.taxCostInvoiceList = taxCostInvoiceList;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getEmployeeDepartment() {
        return employeeDepartment;
    }

    public void setEmployeeDepartment(String employeeDepartment) {
        this.employeeDepartment = employeeDepartment;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getBillCode() {
        return billCode;
    }

    public String getBackOrDelName() {
        return backOrDelName;
    }

    public void setBackOrDelName(String backOrDelName) {
        this.backOrDelName = backOrDelName;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
}
